==> kbibtex-0.1.3.tar.bz2: kbibtex-0.1.3/src/bibtexfile.cpp <==
/***************************************************************************
*   Copyright (C) 2004-2005 by Thomas Fischer                             *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#include <qfile.h>
#include <qtextstream.h>
#include <qiodevice.h>
#include <qstringlist.h>

#include <settings.h>
#include <bibtexfile.h>
#include <bibtexentry.h>
#include <bibtexelement.h>
#include <bibtexstring.h>
#include <bibtexcomment.h>
#include <bibtexfileexporter.h>

namespace BibTeX
{

    BibTeXFile::BibTeXFile( ) : QObject( ), m_preamble( QString::null )
    {
        // nothing
    }

    BibTeXFile::~BibTeXFile()
    {
        for ( ElementList::iterator it = elements.begin(); it != elements.end(); it++ )
            delete * it;
    }

    unsigned int BibTeXFile::count ()
    {
        return elements.count();
    }

    BibTeXElement* BibTeXFile::at( const unsigned int index )
    {
        return * ( elements.at( index ) );
    }

    void BibTeXFile::append( BibTeXFile *other )
    {
        for ( ElementList::iterator it = other->elements.begin(); it != other->elements.end(); it++ )
        {
            BibTeX::BibTeXElement *element = *it;

            BibTeX::BibTeXEntry *entry = dynamic_cast<BibTeX::BibTeXEntry*>( element );
            if ( entry )
                appendElement( new BibTeX::BibTeXEntry( entry ) );
            else
            {
                BibTeX::BibTeXString *string = dynamic_cast<BibTeX::BibTeXString*>( element );
                if ( string )
                    appendElement( new BibTeX::BibTeXString( string ) );
                else
                {
                    BibTeX::BibTeXComment *comment = dynamic_cast<BibTeX::BibTeXComment*>( element );
                    if ( comment )
                        appendElement( new BibTeX::BibTeXComment( comment ) );
                    else
                        qDebug( "Unknown element to add" );
                }
            }
        }

    }

    void BibTeXFile::appendElement( BibTeXElement *element )
    {
        elements.append( element );
    }

    void BibTeXFile::deleteElement( BibTeXElement *element )
    {
        for ( ElementList::iterator it = elements.begin(); it != elements.end(); it++ )
            if ( *it == element )
            {
                elements.remove( it );
                break;
            }

        delete element;
    }

    QString BibTeXFile::preamble()
    {
        return m_preamble;
    }

    void BibTeXFile::setPreamble( const QString &preamble )
    {
        m_preamble = preamble;
    }

    void BibTeXFile::insert( BibTeXFile *bibtexfile )
    {
        for ( unsigned int i = 0; i < bibtexfile->count(); i++ )
        {
            BibTeXElement* originalElement = bibtexfile->at( i );

            BibTeXEntry* originalEntry = dynamic_cast<BibTeXEntry*>( originalElement );
            if ( originalEntry != NULL )
                appendElement( new BibTeXEntry( originalEntry ) );
            else
            {
                BibTeXComment* originalComment = dynamic_cast<BibTeXComment*>( originalElement );
                if ( originalComment != NULL )
                    appendElement( new BibTeXComment( originalComment ) );
                else
                {
                    BibTeXString* originalString = dynamic_cast<BibTeXString*>( originalElement );
                    if ( originalString != NULL )
                        appendElement ( new BibTeXString( originalString ) );
                }
            }
        }
    }

    BibTeXElement *BibTeXFile::containsKey( const QString &key )
    {
        for ( ElementList::iterator it = elements.begin(); it != elements.end();it++ )
        {
            BibTeXEntry* entry = dynamic_cast<BibTeXEntry*>( *it );
            if ( entry != NULL )
            {
                if ( entry->id().compare( key ) == 0 )
                    return entry;
            }
            else
            {
                BibTeXString* string = dynamic_cast<BibTeXString*>( *it );
                if ( string != NULL )
                {
                    if ( string->key().compare( key ) == 0 )
                        return string;
                }
            }
        }

        return NULL;
    }
}

#include "bibtexfile.moc"

==> kbibtex-0.1.4.tar.bz2: kbibtex-0.1.4/src/bibtexfile.cpp <==
/***************************************************************************
*   Copyright (C) 2004-2005 by Thomas Fischer                             *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#include <qfile.h>
#include <qtextstream.h>
#include <qiodevice.h>
#include <qstringlist.h>

#include <settings.h>
#include <bibtexfile.h>
#include <bibtexentry.h>
#include <bibtexelement.h>
#include <bibtexstring.h>
#include <bibtexcomment.h>
#include <bibtexfileexporter.h>

namespace BibTeX
{

    BibTeXFile::BibTeXFile( ) : QObject( ), m_preamble( QString::null )
    {
        // nothing
    }

    BibTeXFile::~BibTeXFile()
    {
        for ( ElementList::iterator it = elements.begin(); it != elements.end(); it++ )
            delete * it;
    }

    unsigned int BibTeXFile::count ()
    {
        return elements.count();
    }

    BibTeXElement* BibTeXFile::at( const unsigned int index )
    {
        return * ( elements.at( index ) );
    }

    void BibTeXFile::append( BibTeXFile *other, BibTeXElement *before )
    {
        ElementList::iterator beforeIt = elements.begin();
        for ( ; beforeIt != elements.end(); beforeIt++ )
            if ( (*beforeIt) == before )
                break;

        for ( ElementList::iterator it = other->elements.begin(); it != other->elements.end(); it++ )
        {
            BibTeX::BibTeXElement *element = *it;

            BibTeX::BibTeXEntry *entry = dynamic_cast<BibTeX::BibTeXEntry*>( element );
            if ( entry )
                appendElement( new BibTeX::BibTeXEntry( entry ), beforeIt );
            else
            {
                BibTeX::BibTeXString *string = dynamic_cast<BibTeX::BibTeXString*>( element );
                if ( string )
                    appendElement( new BibTeX::BibTeXString( string ), beforeIt );
                else
                {
                    BibTeX::BibTeXComment *comment = dynamic_cast<BibTeX::BibTeXComment*>( element );
                    if ( comment )
                        appendElement( new BibTeX::BibTeXComment( comment ), beforeIt );
                    else
                        qDebug( "Unknown element to add" );
                }
            }
        }

    }

    void BibTeXFile::appendElement( BibTeXElement *element )
    {
        elements.append( element );
    }

    void BibTeXFile::appendElement( BibTeXElement *element, ElementList::iterator& it )
    {
        elements.insert( it, element );
    }

    void BibTeXFile::deleteElement( BibTeXElement *element )
    {
        for ( ElementList::iterator it = elements.begin(); it != elements.end(); it++ )
            if ( *it == element )
            {
                elements.remove( it );
                break;
            }

        delete element;
    }

    QString BibTeXFile::preamble()
    {
        return m_preamble;
    }

    void BibTeXFile::setPreamble( const QString &preamble )
    {
        m_preamble = preamble;
    }

    //     void BibTeXFile::insert( BibTeXFile *bibtexfile )
    //     {
    //         for ( unsigned int i = 0; i < bibtexfile->count(); i++ )
    //         {
    //             BibTeXElement* originalElement = bibtexfile->at( i );
    //
    //             BibTeXEntry* originalEntry = dynamic_cast<BibTeXEntry*>( originalElement );
    //             if ( originalEntry != NULL )
    //                 appendElement( new BibTeXEntry( originalEntry ) );
    //             else
    //             {
    //                 BibTeXComment* originalComment = dynamic_cast<BibTeXComment*>( originalElement );
    //                 if ( originalComment != NULL )
    //                     appendElement( new BibTeXComment( originalComment ) );
    //                 else
    //                 {
    //                     BibTeXString* originalString = dynamic_cast<BibTeXString*>( originalElement );
    //                     if ( originalString != NULL )
    //                         appendElement ( new BibTeXString( originalString ) );
    //                 }
    //             }
    //         }
    //     }

    BibTeXElement *BibTeXFile::containsKey( const QString &key )
    {
        for ( ElementList::iterator it = elements.begin(); it != elements.end();it++ )
        {
            BibTeXEntry* entry = dynamic_cast<BibTeXEntry*>( *it );
            if ( entry != NULL )
            {
                if ( entry->id().compare( key ) == 0 )
                    return entry;
            }
            else
            {
                BibTeXString* string = dynamic_cast<BibTeXString*>( *it );
                if ( string != NULL )
                {
                    if ( string->key().compare( key ) == 0 )
                        return string;
                }
            }
        }

        return NULL;
    }
}

#include "bibtexfile.moc"
